pub enum JoinError {
NoHandleFound,
ThreadPanic(Box<dyn Any + Send + 'static>),
}Variants
NoHandleFound
Indicates that no thread was available to be joined.
ThreadPanic(Box<dyn Any + Send + 'static>)
Indicates that the joined thread panicked with the given value.